Learn R Programming

metamicrobiomeR (version 1.2)

gtab.3stud: Test datasets for microbiome age prediction.

Description

A list of three datasets to be used as test datasets for microbiome age prediction using Random Forest model.

Usage

data(gtab.3stud)

Arguments

Format

A list of three dataframes.

References

Subramanian et al. Nature. 2014 Jun 19; 510(7505): 417<U+2013>421. (PubMed)

Bender et al. Sci Transl Med. 2016 Jul 27; 8(349): 349ra100. (PubMed)

Pannaraj et al. JAMA Pediatr. 2017;90095(7):647<U+2013>54. (PubMed)

Thompson et al. Front Cell Infect Microbiol. 2015;5:3. (PubMed)

Examples

Run this code
# NOT RUN {
data(gtab.3stud)
# }

Run the code above in your browser using DataLab