powered by
This function summarizes taxa/pathway abundance tables to provide mean, sd, count by groups.
taxa.meansdn( taxtab, sumvar, groupvar, percent.filter = 0.05, relabund.filter = 5e-05, othervar = "none" )
taxa/pathway abundance table from phylum to species or any preferred highest taxa level.
main variable for summary
variable to be stratified.
prevalence threshold (the percentage of number of samples the taxa/pathway available). Default is 0.05.
relative abundance threshold (the minimum of the average relative abundance for a taxa/pathway to be retained). Default is 0.00005.
vector of variables that are not abundance variables to be summarized. Default is "none".
table of mean, sd, count by group.
# NOT RUN { #Load summary tables of bacterial taxa relative abundance from Bangladesh data data(taxtab6) taxa.meansdn.rm<-taxa.meansdn(taxtab=taxtab6,sumvar="bf",groupvar="age.sample") # }
Run the code above in your browser using DataLab